'use strict';

var helper = require('./helper.js');
var l33tTable = require('./data/l33tTable.js');
var adjacencyGraphs = require('./data/adjacencyGraphs.js');
var translationKeys = require('./data/translationKeys.js');

class Options {
  constructor() {
    this.dictionary = {
      userInput: []
    };
    this.availableGraphs = [];
  }

  setOptions(options = {}) {
    if (options.l33tTable) {
      this.l33tTable = options.l33tTable;
    } else if (!this.l33tTable) {
      this.l33tTable = l33tTable;
    }

    if (options.dictionary) {
      this.dictionary = options.dictionary;
    }

    if (options.translations) {
      this.setTranslations(options.translations);
    } else if (!this.translations) {
      this.setTranslations(translationKeys);
    }

    if (options.graphs) {
      this.setAdjacencyGraphs(options.graphs);
    } else if (!this.graphs) {
      this.setAdjacencyGraphs(adjacencyGraphs);
    }

    this.setRankedDictionaries();
  }

  setTranslations(translations) {
    if (this.checkCustomTranslations(translations)) {
      this.translations = translations;
    } else {
      throw new Error('Invalid translations object fallback to keys');
    }
  }

  checkCustomTranslations(translations) {
    let valid = true;
    Object.keys(translationKeys).forEach(type => {
      if (type in translations) {
        Object.keys(translationKeys[type]).forEach(key => {
          if (!(key in translations[type])) {
            valid = false;
          }
        });
      } else {
        valid = false;
      }
    });
    return valid;
  }

  setRankedDictionaries() {
    const rankedDictionaries = {};
    Object.keys(this.dictionary).forEach(name => {
      const list = this.dictionary[name];

      if (name === 'userInputs') {
        const sanitizedInputs = [];
        list.forEach(input => {
          const inputType = typeof input;

          if (inputType === 'string' || inputType === 'number' || inputType === 'boolean') {
            sanitizedInputs.push(input.toString().toLowerCase());
          }
        });
        rankedDictionaries[name] = helper.buildRankedDictionary(sanitizedInputs);
      } else {
        rankedDictionaries[name] = helper.buildRankedDictionary(list);
      }
    });
    this.rankedDictionaries = rankedDictionaries;
  }

  setAdjacencyGraphs(adjacencyGraphs) {
    if (adjacencyGraphs) {
      this.graphs = adjacencyGraphs;
      this.availableGraphs = Object.keys(adjacencyGraphs);
    }
  }

}

var Options$1 = new Options();

module.exports = Options$1;
//# sourceMappingURL=Options.js.map
