'use strict';

var Options = require('./Options.js');
var scoring = require('./scoring.js');
var Matching = require('./Matching.js');
var TimeEstimates = require('./TimeEstimates.js');
var Feedback = require('./Feedback.js');

const time = () => new Date().getTime();

var index = ((password, options = {}) => {
  Options.setOptions(options);
  const feedback = new Feedback();
  const matching = new Matching();
  const timeEstimates = new TimeEstimates();
  const start = time();
  const matches = matching.match(password);
  const matchSequence = scoring.mostGuessableMatchSequence(password, matches);
  const calcTime = time() - start;
  const attackTimes = timeEstimates.estimateAttackTimes(matchSequence.guesses);
  return {
    calcTime,
    ...matchSequence,
    ...attackTimes,
    // @ts-ignore
    feedback: feedback.getFeedback(attackTimes.score, matchSequence.sequence)
  };
});

module.exports = index;
//# sourceMappingURL=index.js.map
